# Changelog

<!--next-version-placeholder-->

## v0.1.50 (2021-02-17)
### Fix
* **fhempy:** Fix cryptography installation ([`a7b4b6e`](https://github.com/dominikkarall/fhempy/commit/a7b4b6e5a5357f6b409656f4f79d99ce1b6154a3))

## v0.1.49 (2021-02-14)
### Feature
* **xiaomi_gateway3:** Update to latest version ([`9643837`](https://github.com/dominikkarall/fhempy/commit/96438373925c4c583dfbe4a9d8433fbc98aa678a))

### Fix
* **xiaomi_tokens:** Fix create miio device ([`f8e4352`](https://github.com/dominikkarall/fhempy/commit/f8e43525f62f00939f60d0ee30349246203682db))

## v0.1.48 (2021-02-02)
### Fix
* **xiaomi_tokens:** Fix device creation ([`ebbc3bb`](https://github.com/dominikkarall/fhempy/commit/ebbc3bb61f20fba4ff8d1eadd1af61017abe956e))

## v0.1.47 (2021-02-01)
### Fix
* **xiaomi_tokens:** Make readings country specific ([`efe1b7a`](https://github.com/dominikkarall/fhempy/commit/efe1b7a4f37d3530b2f92a906e45f202d67e6d21))

## v0.1.46 (2021-02-01)
### Fix
* **fhempy:** Raise error if pkg install fails ([`8b15dcd`](https://github.com/dominikkarall/fhempy/commit/8b15dcd19180451b45f3de4aa420938334f951d2))

## v0.1.45 (2021-01-31)
### Fix
* **xiaomi_gateway3:** Sort imports ([`89c14bc`](https://github.com/dominikkarall/fhempy/commit/89c14bc1477a91be51c86a80666f12e94430cb04))
* **googlecast:** Remove spotify_token dependency ([`ab8f872`](https://github.com/dominikkarall/fhempy/commit/ab8f8726158eb7037a62e98517a61b2760fbc47f))
* **xiaomi_gateway3:** Fix motion sensor reset ([`37222fc`](https://github.com/dominikkarall/fhempy/commit/37222fcd1d52c09cb97ba5943d939436c40d56a8))

## v0.1.44 (2021-01-30)
### Fix
* **fhempy:** Change logfile name to fhempy ([`2dc88df`](https://github.com/dominikkarall/fhempy/commit/2dc88df1177c69990926d5e55852656ee365f666))
* **xiaomi_gateway3:** Remove added_device reading ([`700e361`](https://github.com/dominikkarall/fhempy/commit/700e361417c9fc4ea634874b2f447396657c85fc))
* **fhempy:** Change log name to fhempy ([`ce8fac5`](https://github.com/dominikkarall/fhempy/commit/ce8fac5e3faa8fa8db360d787dc481288ba045f0))

## v0.1.43 (2021-01-30)


## v0.1.42 (2021-01-30)
### Feature
* **eq3bt:** Support wndOpnTime/Temp, eco/cmftTemp ([`107805f`](https://github.com/dominikkarall/fhempy/commit/107805fd5d85fde76a49e2fabe1994943d27a169))

## v0.1.41 (2021-01-30)


## v0.1.40 (2021-01-30)
### Feature
* **xiaomi_gateway3:** Support sensor_wleak.aq1 ([`bc8cf61`](https://github.com/dominikkarall/fhempy/commit/bc8cf6183bb4568b5f47b98e07669e3e8cda4f4e))

### Fix
* **fhempy:** Fix update ([`6f381c1`](https://github.com/dominikkarall/fhempy/commit/6f381c1be050f3ee26d4cbd236b2e2da447c581f))
* **object_detection:** Fix image detection ([`cc5c8de`](https://github.com/dominikkarall/fhempy/commit/cc5c8defa3457d5a60d812c062623654ed3b0e9e))
* **esphome:** Fix restart ([`be47a72`](https://github.com/dominikkarall/fhempy/commit/be47a7221fc1814c091992393652c4c767a8b203))

## v0.1.39 (2021-01-29)
### Feature
* **xiaomi_gateway3:** Support motion sensor ([`478db7a`](https://github.com/dominikkarall/fhempy/commit/478db7ad578ae6fef5a18066b2a4058fe561f745))
* **tuya:** Support another heating device ([`8843138`](https://github.com/dominikkarall/fhempy/commit/884313823231407a2155518cc01d04930246313c))

## v0.1.38 (2021-01-28)
### Fix
* **eq3bt:** Fix set temperatureOffset ([`429afcd`](https://github.com/dominikkarall/fhempy/commit/429afcd4f61f17b248dce60161d7418ec5770a54))

## v0.1.37 (2021-01-28)
### Fix
* **xiaomi_gateway3:** Add missing imports ([`b54aa4a`](https://github.com/dominikkarall/fhempy/commit/b54aa4a2529f1c7c23c3bfbb457c05790dcc0014))
* **fhempy:** Set IODev after CommandDefine ([`b1a1299`](https://github.com/dominikkarall/fhempy/commit/b1a12993b76cebe3949f510add7a7e1857b91869))

### Documentation
* Remove useless stuff ([`7401907`](https://github.com/dominikkarall/fhempy/commit/74019075190fb53b2cc7fdf6e4721360a698974e))

## v0.1.31 (2021-01-27)
### Feature
* **tuya:** Add keep_connected attr ([`b2c1ca4`](https://github.com/dominikkarall/fhempy/commit/b2c1ca47cf1b7adda9eb86731f21e0f755cf3dcd))

## v0.1.30 (2021-01-27)
### Fix
* **xiaomi_gateway3:** Remove unused imports ([`1758909`](https://github.com/dominikkarall/fhem_pythonbinding/commit/175890932f4efeeedba79ae6b2d1dfe81839abcc))

## v0.1.29 (2021-01-27)
### Fix
* **xiaomi_gateway3:** Add import time ([`7ef7a9e`](https://github.com/dominikkarall/fhem_pythonbinding/commit/7ef7a9ecabb2e8f765f6e1223bcaaaed365c6644))
* **xiaomi_gateway3:** Set last_update on update ([`146487d`](https://github.com/dominikkarall/fhem_pythonbinding/commit/146487daf69f9ed5219043c444fdfbac9f90021c))

## v0.1.28 (2021-01-27)
### Feature
* New reading pairing on/off ([`ee42b9c`](https://github.com/dominikkarall/fhem_pythonbinding/commit/ee42b9c1dc822993ee882e94be056b311f87bd8e))

## v0.1.27 (2021-01-27)
### Fix
* Pychromecast min version ([`8a58a53`](https://github.com/dominikkarall/fhem_pythonbinding/commit/8a58a5374c25ffcaf1f3c9a9f37b5ebb83272d96))
